@@ -1,6 +1,25 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * gtk-combo-text: A combo box for selecting from a list.
+ * gtk-combo-text.c - A combo box for selecting from a list.
+ * Copyright 2000, 2001, Ximian, Inc.
+ *
+ * Authors:
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License, version 2, as published by the Free Software Foundation.
+ *
+ * This library is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  */
+
 #include <config.h>
 #include <ctype.h>
 #include <gtk/gtksignal.h>
@@ -28,11 +47,15 @@ gtk_combo_text_destroy (GtkObject *object)
 		g_hash_table_destroy (ct->elements);
 		ct->elements = NULL;
 	}
-	gtk_signal_disconnect_by_func (GTK_OBJECT (ct),
-				       GTK_SIGNAL_FUNC (cb_pop_down), NULL);
-	gtk_signal_disconnect_by_func (GTK_OBJECT (ct->list),
-				       GTK_SIGNAL_FUNC (list_unselect_cb),
-				       (gpointer) ct);
+	if (ct->list != NULL) {
+		gtk_signal_disconnect_by_func (GTK_OBJECT (ct),
+					       GTK_SIGNAL_FUNC (cb_pop_down), NULL);
+		gtk_signal_disconnect_by_func (GTK_OBJECT (ct->list),
+					       GTK_SIGNAL_FUNC (list_unselect_cb),
+					       (gpointer) ct);
+		ct->list = NULL;
+	}
+
 	(*gtk_combo_text_parent_class->destroy) (object);
 }
 
@@ -345,7 +368,7 @@ cb_list_mapped (GtkWidget *widget, gpointer user_data)
 		gtk_widget_grab_focus (GTK_WIDGET ((list->selection->data)));
 }
 
-static void
+void
 gtk_combo_text_construct (GtkComboText *ct, gboolean const is_scrolled)
 {
 	GtkWidget *entry, *list, *scroll, *display_widget;
@@ -395,6 +418,8 @@ gtk_combo_text_construct (GtkComboText *ct, gboolean const is_scrolled)
 	gtk_widget_show (display_widget);
 	gtk_widget_show (entry);
 	gtk_combo_box_construct (GTK_COMBO_BOX (ct), entry, display_widget);
+	gtk_signal_connect (GTK_OBJECT (ct), "pop_down_done",
+			    GTK_SIGNAL_FUNC (cb_pop_down), NULL);
 }
 
 GtkWidget*
@@ -404,8 +429,6 @@ gtk_combo_text_new (gboolean const is_scrolled)
 
 	ct = gtk_type_new (gtk_combo_text_get_type ());
 	gtk_combo_text_construct (ct, is_scrolled);
-	gtk_signal_connect (GTK_OBJECT (ct), "pop_down_done",
-			    GTK_SIGNAL_FUNC (cb_pop_down), NULL);
 	return GTK_WIDGET (ct);
 }
 
