@@ -45,7 +45,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static gint color_combo_signals [LAST_SIGNAL] = { 0, };
+static guint color_combo_signals [LAST_SIGNAL] = { 0, };
 
 static GObjectClass *color_combo_parent_class;
 
@@ -82,14 +82,13 @@ color_combo_class_init (GObjectClass *object_class)
 
 	color_combo_signals [CHANGED] =
 		gtk_signal_new (
-			"changed",
+			"color_changed",
 			GTK_RUN_LAST,
 			E_OBJECT_CLASS_TYPE (object_class),
-			GTK_SIGNAL_OFFSET (ColorComboClass, changed),
-			e_marshal_NONE__POINTER_BOOLEAN,
-			GTK_TYPE_NONE, 2, GTK_TYPE_POINTER, GTK_TYPE_BOOL);
-
-	E_OBJECT_CLASS_ADD_SIGNALS (object_class, color_combo_signals, LAST_SIGNAL);
+			GTK_SIGNAL_OFFSET (ColorComboClass, color_changed),
+			e_marshal_NONE__POINTER_BOOLEAN_BOOLEAN_BOOLEAN,
+			GTK_TYPE_NONE, 4, GTK_TYPE_POINTER,
+			GTK_TYPE_BOOL, GTK_TYPE_BOOL, GTK_TYPE_BOOL);
 }
 
 GtkType
@@ -116,34 +115,33 @@ color_combo_get_type (void)
 }
 
 /*
- * Fires signal "changed" with the current color as its param
+ * Fires signal "color_changed" with the current color as its param
  */
 static void
-emit_change (ColorCombo *cc, GdkColor *color, gboolean by_user)
+emit_color_changed (ColorCombo *cc, GdkColor *color,
+		    gboolean is_custom, gboolean by_user, gboolean is_default)
 {
-  	gtk_signal_emit (
-		GTK_OBJECT (cc),
+  	gtk_signal_emit (GTK_OBJECT (cc),
 		color_combo_signals [CHANGED],
-		color, by_user);
+		color, is_custom, by_user, is_default);
 	gtk_combo_box_popup_hide (GTK_COMBO_BOX (cc));
 }
 
 static void
-cb_color_change (ColorPalette *P, GdkColor *color,
-		 gboolean custom, gboolean by_user,
+cb_palette_color_changed (ColorPalette *P, GdkColor *color,
+		 gboolean custom, gboolean by_user, gboolean is_default,
 		 ColorCombo *cc)
 {
 	color_combo_set_color_internal (cc, color);
-		
-	emit_change (cc, color, by_user);
+	emit_color_changed (cc, color, custom, by_user, is_default);
 }
 
 static void
 preview_clicked (GtkWidget *button, ColorCombo *cc)
 {
-	GdkColor *color = color_palette_get_current_color (cc->palette);
-	emit_change (cc, color, TRUE);
-	
+	gboolean is_default;
+	GdkColor *color = color_palette_get_current_color (cc->palette, &is_default);
+	emit_color_changed (cc, color, FALSE, TRUE, is_default);
 	if (color)
 		gdk_color_free (color);
 }
@@ -164,8 +162,8 @@ color_table_setup (ColorCombo *cc,
 	g_return_if_fail (cc != NULL);
 
 	/* Tell the palette that we will be changing it's custom colors */
-	cc->palette = 
-		COLOR_PALETTE (color_palette_new (no_color_label, 
+	cc->palette =
+		COLOR_PALETTE (color_palette_new (no_color_label,
 						  cc->default_color,
 						  color_group));
 
@@ -174,15 +172,24 @@ color_table_setup (ColorCombo *cc,
 		gtk_signal_connect (GTK_OBJECT (picker), "clicked",
 				    GTK_SIGNAL_FUNC (cb_cust_color_clicked), cc);
 	}
-	
-	gtk_signal_connect (GTK_OBJECT (cc->palette), "changed",
-			    GTK_SIGNAL_FUNC (cb_color_change), cc);
+
+	gtk_signal_connect (GTK_OBJECT (cc->palette), "color_changed",
+			    GTK_SIGNAL_FUNC (cb_palette_color_changed), cc);
 
 	gtk_widget_show_all (GTK_WIDGET (cc->palette));
 
 	return;
 }
 
+void
+color_combo_box_set_preview_relief (ColorCombo *cc, GtkReliefStyle relief)
+{
+	g_return_if_fail (cc != NULL);
+	g_return_if_fail (IS_COLOR_COMBO (cc));
+
+	gtk_button_set_relief (GTK_BUTTON (cc->preview_button), relief);
+}
+
 /*
  * Where the actual construction goes on
  */
@@ -212,7 +219,8 @@ color_combo_construct (ColorCombo *cc, GdkPixbuf *icon,
 			"y",      0.0,
 			"anchor", GTK_ANCHOR_NW,
 			NULL);
-		
+		gdk_pixbuf_unref (icon);
+
 		cc->preview_color_item = gnome_canvas_item_new (
 			GNOME_CANVAS_GROUP (gnome_canvas_root (cc->preview_canvas)),
 			gnome_canvas_rect_get_type (),
@@ -234,25 +242,22 @@ color_combo_construct (ColorCombo *cc, GdkPixbuf *icon,
 			"fill_color", "black",
 			"width_pixels", 1,
 			NULL);
-	
+
 	gtk_container_add (GTK_CONTAINER (cc->preview_button), GTK_WIDGET (cc->preview_canvas));
 	gtk_widget_set_usize (GTK_WIDGET (cc->preview_canvas), 24, 24);
 	gtk_signal_connect (GTK_OBJECT (cc->preview_button), "clicked",
 			    GTK_SIGNAL_FUNC (preview_clicked), cc);
-	
-	/*
-	 * Our table selector
-	 */
+
 	color_table_setup (cc, no_color_label, color_group);
-	
+
 	gtk_widget_show_all (cc->preview_button);
-	
+
 	gtk_combo_box_construct (GTK_COMBO_BOX (cc),
 				 cc->preview_button,
 				 GTK_WIDGET (cc->palette));
 
-	/* Set our color to the current color on the palette */
-	color_combo_set_color_internal (cc, color_palette_get_current_color (cc->palette));
+	color_combo_set_color_internal (cc,
+		color_palette_get_current_color (cc->palette, NULL));
 }
 
 /* color_combo_get_color:
@@ -260,23 +265,44 @@ color_combo_construct (ColorCombo *cc, GdkPixbuf *icon,
  * Return current color, result must be freed with gdk_color_free !
  */
 GdkColor *
-color_combo_get_color (ColorCombo *cc)
+color_combo_get_color (ColorCombo *cc, gboolean *is_default)
 {
-	return color_palette_get_current_color (cc->palette);
+	return color_palette_get_current_color (cc->palette, is_default);
 }
 
+/**
+ * color_combo_set_color
+ * @cc     The combo
+ * @color  The color
+ *
+ * Set the color of the combo to the given color. Causes the color_changed
+ * signal to be emitted.
+ */
 void
 color_combo_set_color (ColorCombo *cc, GdkColor *color)
 {
-	/* This will change the color on the palette than
-	 * it will invoke cb_color_change which will call emit_change
-	 * and set_color_internal which will change the color on
-	 * our preview and will let the users of the combo know
-	 * that the current color has changed
+	/* This will change the color on the palette than it will invoke
+	 * cb_palette_color_changed which will call emit_color_changed and
+	 * set_color_internal which will change the color on our preview and
+	 * will let the users of the combo know that the current color has
+	 * changed
 	 */
 	color_palette_set_current_color (cc->palette, color);
 }
 
+/**
+ * color_combo_set_color_to_default
+ * @cc  The combo
+ *
+ * Set the color of the combo to the default color. Causes the color_changed
+ * signal to be emitted.
+ */
+void
+color_combo_set_color_to_default (ColorCombo *cc)
+{
+	color_palette_set_color_to_default (cc->palette);
+}
+
 /**
  * color_combo_new :
  * icon : optionally NULL.
@@ -287,7 +313,7 @@ color_combo_set_color (ColorCombo *cc, GdkColor *color)
 GtkWidget *
 color_combo_new (GdkPixbuf *icon, char const *no_color_label,
 		 GdkColor *default_color,
-		 ColorGroup  *color_group)
+		 ColorGroup *color_group)
 {
 	ColorCombo *cc;
 
